@@ -332,6 +332,8 @@ class H5MDReader(base.ReaderBase):
        Adds :meth:`parse_n_atoms` method to obtain the number of atoms directly
        from the trajectory by evaluating the shape of the ``position``,
        ``velocity``, or ``force`` groups.
+    .. versionchanged:: 2.5.0
+       Add correct handling of simple cuboid boxes
 
     """
 
@@ -640,8 +642,17 @@ class H5MDReader(base.ReaderBase):
 
         # Sets frame box dimensions
         # Note: H5MD files must contain 'box' group in each 'particles' group
-        if 'edges' in particle_group['box']:
-            ts.dimensions = core.triclinic_box(*particle_group['box/edges/value'][frame, :])
+        if "edges" in particle_group["box"]:
+            edges = particle_group["box/edges/value"][frame, :]
+            # A D-dimensional vector or a D × D matrix, depending on the
+            # geometry of the box, of Float or Integer type. If edges is a
+            # vector, it specifies the space diagonal of a cuboid-shaped box.
+            # If edges is a matrix, the box is of triclinic shape with the edge
+            # vectors given by the rows of the matrix.
+            if edges.shape == (3,):
+                ts.dimensions = [*edges, 90, 90, 90]
+            else:
+                ts.dimensions = core.triclinic_box(*edges)
         else:
             ts.dimensions = None
 
