@@ -23,6 +23,7 @@
 from glob import glob
 import itertools
 from os import path
+import pickle
 
 import numpy as np
 
@@ -125,11 +126,11 @@ class TestAtomGroupWriting(object):
     def test_write_frames(self, u, tmpdir, frames):
         destination = str(tmpdir / 'test.dcd')
         selection = u.trajectory[frames]
-        ref_positions = np.stack([ts.positions for ts in selection])
+        ref_positions = np.stack([ts.positions.copy() for ts in selection])
         u.atoms.write(destination, frames=frames)
 
         u_new = mda.Universe(destination)
-        new_positions = np.stack([ts.positions for ts in u_new.trajectory])
+        new_positions = np.stack([ts.positions.copy() for ts in u_new.trajectory])
 
         assert_array_almost_equal(new_positions, ref_positions)
 
@@ -141,11 +142,11 @@ class TestAtomGroupWriting(object):
     def test_write_frame_iterator(self, u, tmpdir, frames):
         destination = str(tmpdir / 'test.dcd')
         selection = u.trajectory[frames]
-        ref_positions = np.stack([ts.positions for ts in selection])
+        ref_positions = np.stack([ts.positions.copy() for ts in selection])
         u.atoms.write(destination, frames=selection)
 
         u_new = mda.Universe(destination)
-        new_positions = np.stack([ts.positions for ts in u_new.trajectory])
+        new_positions = np.stack([ts.positions.copy() for ts in u_new.trajectory])
 
         assert_array_almost_equal(new_positions, ref_positions)
 
@@ -165,8 +166,8 @@ class TestAtomGroupWriting(object):
         destination = str(tmpdir / 'test.dcd' + compression)
         u.atoms.write(destination, frames='all')
         u_new = mda.Universe(destination)
-        ref_positions = np.stack([ts.positions for ts in u.trajectory])
-        new_positions = np.stack([ts.positions for ts in u_new.trajectory])
+        ref_positions = np.stack([ts.positions.copy() for ts in u.trajectory])
+        new_positions = np.stack([ts.positions.copy() for ts in u_new.trajectory])
         assert_array_almost_equal(new_positions, ref_positions)
 
     @pytest.mark.parametrize('frames', ('invalid', 8, True, False, 3.2))
@@ -873,6 +874,12 @@ class TestDihedralSelections(object):
         rssel = [r.chi1_selection() for r in resgroup]
         assert_equal(rgsel, rssel)
 
+    @pytest.mark.parametrize("resname", ["CYS", "ILE", "SER", "THR", "VAL"])
+    def test_chi1_selections_non_cg(self, resname, PSFDCD):
+        resgroup = PSFDCD.select_atoms(f"resname {resname}").residues
+        rgsel = resgroup.chi1_selections()
+        assert not any(sel is None for sel in rgsel)
+
     @pytest.mark.parametrize("resname", ["CYSH", "ILE", "SER", "THR", "VAL"])
     def test_chi1_selection_non_cg_gromacs(self, resname, TPR):
         resgroup = TPR.select_atoms(f"resname {resname}").residues
@@ -993,7 +1000,8 @@ class TestUnwrapFlag(object):
             np.array([[7333.79167791, -211.8997285, -721.50785456],
                       [-211.8997285, 7059.07470427, -91.32156884],
                       [-721.50785456, -91.32156884, 6509.31735029]]),
-        'asphericity': 0.02060121,
+        'asphericity': np.array([0.135, 0.047, 0.094]),
+        'shape_parameter': np.array([-0.112, -0.004,  0.02]),
     }
 
     ref_Unwrap_residues = {
@@ -1008,7 +1016,8 @@ class TestUnwrapFlag(object):
         'moment_of_inertia': np.array([[16687.941, -1330.617, 2925.883],
                                        [-1330.617, 19256.178, 3354.832],
                                        [2925.883,  3354.832, 8989.946]]),
-        'asphericity': 0.2969491080,
+        'asphericity': np.array([0.61 , 0.701, 0.381]),
+        'shape_parameter': np.array([-0.461,  0.35 ,  0.311]),
     }
 
     ref_noUnwrap = {
@@ -1018,6 +1027,7 @@ class TestUnwrapFlag(object):
                                        [0.0, 98.6542, 0.0],
                                        [0.0, 0.0, 98.65421327]]),
         'asphericity': 1.0,
+        'shape_parameter': 1.0,
     }
 
     ref_Unwrap = {
@@ -1027,6 +1037,7 @@ class TestUnwrapFlag(object):
                                        [0.0, 132.673, 0.0],
                                        [0.0, 0.0, 132.673]]),
         'asphericity': 1.0,
+        'shape_parameter': 1.0,
     }
 
     @pytest.fixture(params=[False, True])  # params indicate shuffling
@@ -1053,7 +1064,8 @@ class TestUnwrapFlag(object):
     @pytest.mark.parametrize('method_name', ('center_of_geometry',
                                              'center_of_mass',
                                              'moment_of_inertia',
-                                             'asphericity'))
+                                             'asphericity',
+                                             'shape_parameter'))
     def test_residues(self, ag, unwrap, ref, method_name):
         method = getattr(ag, method_name)
         if unwrap:
@@ -1789,3 +1801,17 @@ class TestAtomGroupSort(object):
         ref = [6, 5, 4, 3, 2, 1, 0]
         agsort = ag.sort("positions", keyfunc=lambda x: x[:, 1])
         assert np.array_equal(ref, agsort.ix)
+
+
+class TestAtomGroupPickle(object):
+    """Test AtomGroup pickling support."""
+
+    @pytest.fixture()
+    def universe(self):
+        return mda.Universe(PSF, DCD)
+
+    @pytest.mark.parametrize("selection", ("name CA", "segid 4AKE"))
+    def test_atomgroup_pickle(self, universe, selection):
+        sel = universe.select_atoms(selection)
+        atm = pickle.loads(pickle.dumps(sel))
+        assert_almost_equal(sel.positions, atm.positions)
